@@ -1,3 +1,4 @@
+import json
 from restclients_core import models
 from dateutil.parser import parse
 
@@ -26,7 +27,7 @@ class UwEmailForwarding(models.Model):
                 }
 
     def __str__(self):
-        return "{status: %s, permitted: %s, fwd: %s}" % (
+        return "{status: {0}, permitted: {1}, fwd: {2}}".format(
             self.status, self.permitted, self.fwd)
 
 
@@ -34,6 +35,9 @@ class Subscription(models.Model):
     SUBS_OFFICE_356_PILOT = 59
     SUBS_CODE_KERBEROS = 60
     SUBS_CODE_2FA = 64
+    SUBS_CODE_CANVAS_STUDENT = 77
+    SUBS_CODE_CANVAS_AFFILIATE = 78
+    SUBS_CODE_CANVAS_SPONSORED = 79
     SUBS_CODE_U_FORWARDING = 105
     SUBS_CODE_GOOGLE_APPS = 144
     SUBS_CODE_GOOGLE_APPS_TEST = 145
@@ -148,12 +152,7 @@ class Subscription(models.Model):
         return data
 
     def __str__(self):
-        return "{netid: %s, %s: %s, %s: %s, %s: %s, %s: %s}" % (
-            self.uwnetid,
-            "subscription_code", self.subscription_code,
-            "permitted", self.permitted,
-            "status_code", self.status_code,
-            "status_name", self.status_name)
+        return json.dumps(self.json_data())
 
 
 class SubscriptionPostResponse(models.Model):
@@ -183,6 +182,7 @@ class SubscriptionPermit(models.Model):
     STAFF_C_CODE = 4
     FACULTY_C_CODE = 5
     DEPARTMENT_C_CODE = 11
+    COURSE_C_CODE = 12
     CLINICIAN_C_CODE = 13
     STUDENT_EMPLOYEE_C_CODE = 14
     AFFILIATE_EMPLOYEE_C_CODE = 15
@@ -192,6 +192,7 @@ class SubscriptionPermit(models.Model):
     EO_NON_TECHFEE_STUD_C_CODE = 19
     APPLICANT_C_CODE = 20
     RETIREE_C_CODE = 34
+    SYSTEM_ADMIN_C_CODE = 46
     MEDICAL_RESIDENT_C_CODE = 145
     CURRENT_STATUS_CODE = 1
     FORMER_STATUS_CODE = 3
@@ -219,6 +220,9 @@ class SubscriptionPermit(models.Model):
     def is_category_department(self):
         return self.category_code == SubscriptionPermit.DEPARTMENT_C_CODE
 
+    def is_category_course(self):
+        return self.category_code == SubscriptionPermit.COURSE_C_CODE
+
     def is_category_student_employee(self):
         return (
             self.category_code == SubscriptionPermit.STUDENT_EMPLOYEE_C_CODE)
@@ -242,6 +246,9 @@ class SubscriptionPermit(models.Model):
     def is_category_retiree(self):
         return self.category_code == SubscriptionPermit.RETIREE_C_CODE
 
+    def is_category_system_administrator(self):
+        return self.category_code == SubscriptionPermit.SYSTEM_ADMIN_C_CODE
+
     def is_status_current(self):
         return self.status_code == SubscriptionPermit.CURRENT_STATUS_CODE
 
@@ -307,6 +314,7 @@ class Category(models.Model):
     ALTID_SUPPORT_DEPARTMENTAL = 69
     GOOGLE_SUITE_ENDORSEE = 234
     OFFICE_365_ENDORSEE = 235
+    CANVAS_PROVISIONEE = 236
 
     STATUS_ACTIVE = 1
     STATUS_GRACE = 2
@@ -364,10 +372,7 @@ class Category(models.Model):
         return data
 
     def __str__(self):
-        return "{category: %s, %s: %s, %s: %s, %s: %s, %s: %s}" % (
-            self.category_code, self.category_name, self.expiration,
-            self.notify_code, self.notify_date, self.source_code,
-            self.source_name, self.status_code, self.status_name)
+        return json.dumps(self.json_data())
 
 
 def convert_seconds_to_days(interval):
@@ -521,7 +526,37 @@ class Supported(models.Model):
         }
 
     def __str__(self):
-        return "%s" % self.json_data()
+        return json.dumps(self.json_data())
 
     class Meta:
         db_table = "restclients_uwnetid_supported"
+
+
+class Admin(models.Model):
+    name = models.SlugField(max_length=64,
+                            db_index=True,
+                            unique=True)
+    role = models.SlugField(max_length=16, null=True)
+
+    def is_owner(self):
+        return self.role == 'owner' or self.role == 'owner-admin'
+
+    def is_admin(self):
+        return self.role == 'administrator' or self.role == 'owner-admin'
+
+    def from_json(self, data):
+        self.name = data['name']
+        self.role = data.get('role')
+        return self
+
+    def json_data(self):
+        return {
+            'name': self.name,
+            'role': self.role
+        }
+
+    def __str__(self):
+        return json.dumps(self.json_data())
+
+    class Meta:
+        db_table = "restclients_uwnetid_admin"
